@@ -74,3 +74,6 @@ function writeJSON(filename, content) {
 writeJSON('../data.json', data);
 writeJSON('../modules.json', Object.keys(data));
 writeJSON('../external.json', external);
+
+// eslint-disable-next-line no-console
+console.log('\u001B[32mcompat data rebuilt\u001B[0m');
