@@ -1,6 +1,8 @@
 'use strict';
 require('../../modules/es.promise');
 require('../../modules/es.promise.all-settled');
+require('../../modules/es.string.iterator');
+require('../../modules/web.dom-collections.iterator');
 var path = require('../../internals/path');
 
 var Promise = path.Promise;
