@@ -1,5 +1,5 @@
 require('../../modules/es.symbol.has-instance');
 require('../../modules/es.function.has-instance');
-var WrappedWellKnownSymbolModule = require('../../internals/wrapped-well-known-symbol');
+var WrappedWellKnownSymbolModule = require('../../internals/well-known-symbol-wrapped');
 
 module.exports = WrappedWellKnownSymbolModule.f('hasInstance');
