@@ -1,4 +1,4 @@
 require('../../modules/esnext.symbol.pattern-match');
-var WrappedWellKnownSymbolModule = require('../../internals/wrapped-well-known-symbol');
+var WrappedWellKnownSymbolModule = require('../../internals/well-known-symbol-wrapped');
 
 module.exports = WrappedWellKnownSymbolModule.f('patternMatch');
