@@ -1,8 +1,8 @@
 var $ = require('../internals/export');
-var parseFloat = require('../internals/parse-float');
+var parseFloat = require('../internals/number-parse-float');
 
 // `Number.parseFloat` method
-// https://tc39.github.io/ecma262/#sec-number.parseFloat
+// https://tc39.es/ecma262/#sec-number.parseFloat
 $({ target: 'Number', stat: true, forced: Number.parseFloat != parseFloat }, {
   parseFloat: parseFloat
 });
