@@ -4,7 +4,7 @@ var path = require('../internals/path');
 var aFunction = require('../internals/a-function');
 var anObject = require('../internals/an-object');
 var toObject = require('../internals/to-object');
-var createIteratorProxy = require('../internals/create-iterator-proxy');
+var createIteratorProxy = require('../internals/iterator-create-proxy');
 var getIteratorMethod = require('../internals/get-iterator-method');
 
 var Iterator = path.Iterator;
