@@ -4,7 +4,7 @@ var IS_PURE = require('../internals/is-pure');
 var getBuiltIn = require('../internals/get-built-in');
 var anObject = require('../internals/an-object');
 var aFunction = require('../internals/a-function');
-var bind = require('../internals/bind-context');
+var bind = require('../internals/function-bind-context');
 var speciesConstructor = require('../internals/species-constructor');
 var getSetIterator = require('../internals/get-set-iterator');
 var iterate = require('../internals/iterate');
@@ -20,7 +20,7 @@ $({ target: 'Set', proto: true, real: true, forced: IS_PURE }, {
     var adder = aFunction(newSet.add);
     iterate(iterator, function (value) {
       adder.call(newSet, boundFunction(value, value, set));
-    }, undefined, false, true);
+    }, { IS_ITERATOR: true });
     return newSet;
   }
 });
