@@ -1,6 +1,6 @@
 var $ = require('../internals/export');
 var global = require('../internals/global');
-var userAgent = require('../internals/user-agent');
+var userAgent = require('../internals/engine-user-agent');
 
 var slice = [].slice;
 var MSIE = /MSIE .\./.test(userAgent); // <- dirty ie9- check
